@@ -14,6 +14,8 @@
 
 using faiss::Index;
 using faiss::IndexBinary;
+using faiss::IOReader;
+using faiss::IOWriter;
 using faiss::VectorTransform;
 
 int faiss_write_index(const FaissIndex* idx, FILE* f) {
@@ -30,6 +32,19 @@ int faiss_write_index_fname(const FaissIndex* idx, const char* fname) {
     CATCH_AND_HANDLE
 }
 
+int faiss_write_index_custom(
+        const FaissIndex* idx,
+        FaissIOWriter* io_writer,
+        int io_flags) {
+    try {
+        faiss::write_index(
+                reinterpret_cast<const Index*>(idx),
+                reinterpret_cast<IOWriter*>(io_writer),
+                io_flags);
+    }
+    CATCH_AND_HANDLE
+}
+
 int faiss_read_index(FILE* f, int io_flags, FaissIndex** p_out) {
     try {
         auto out = faiss::read_index(f, io_flags);
@@ -49,6 +64,18 @@ int faiss_read_index_fname(
     CATCH_AND_HANDLE
 }
 
+int faiss_read_index_custom(
+        FaissIOReader* io_reader,
+        int io_flags,
+        FaissIndex** p_out) {
+    try {
+        auto out = faiss::read_index(
+                reinterpret_cast<IOReader*>(io_reader), io_flags);
+        *p_out = reinterpret_cast<FaissIndex*>(out);
+    }
+    CATCH_AND_HANDLE
+}
+
 int faiss_write_index_binary(const FaissIndexBinary* idx, FILE* f) {
     try {
         faiss::write_index_binary(reinterpret_cast<const IndexBinary*>(idx), f);
@@ -66,6 +93,17 @@ int faiss_write_index_binary_fname(
     CATCH_AND_HANDLE
 }
 
+int faiss_write_index_binary_custom(
+        const FaissIndexBinary* idx,
+        FaissIOWriter* io_writer) {
+    try {
+        faiss::write_index_binary(
+                reinterpret_cast<const IndexBinary*>(idx),
+                reinterpret_cast<IOWriter*>(io_writer));
+    }
+    CATCH_AND_HANDLE
+}
+
 int faiss_read_index_binary(FILE* f, int io_flags, FaissIndexBinary** p_out) {
     try {
         auto out = faiss::read_index_binary(f, io_flags);
@@ -85,6 +123,18 @@ int faiss_read_index_binary_fname(
     CATCH_AND_HANDLE
 }
 
+int faiss_read_index_binary_custom(
+        FaissIOReader* io_reader,
+        int io_flags,
+        FaissIndexBinary** p_out) {
+    try {
+        auto out = faiss::read_index_binary(
+                reinterpret_cast<IOReader*>(io_reader), io_flags);
+        *p_out = reinterpret_cast<FaissIndexBinary*>(out);
+    }
+    CATCH_AND_HANDLE
+}
+
 int faiss_read_VectorTransform_fname(
         const char* fname,
         FaissVectorTransform** p_out) {
