@@ -1,4 +1,4 @@
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -27,7 +27,9 @@ def make_indices_copy_from_cpu(nlist, d, qtype, by_residual, metric, clamp):
 
     res = faiss.StandardGpuResources()
     res.noTempMemory()
-    idx_gpu = faiss.GpuIndexIVFScalarQuantizer(res, idx_cpu)
+    config = faiss.GpuIndexIVFScalarQuantizerConfig()
+    config.use_cuvs = False
+    idx_gpu = faiss.GpuIndexIVFScalarQuantizer(res, idx_cpu, config)
 
     return idx_cpu, idx_gpu
 
@@ -37,8 +39,10 @@ def make_indices_copy_from_gpu(nlist, d, qtype, by_residual, metric, clamp):
 
     res = faiss.StandardGpuResources()
     res.noTempMemory()
+    config = faiss.GpuIndexIVFScalarQuantizerConfig()
+    config.use_cuvs = False
     idx_gpu = faiss.GpuIndexIVFScalarQuantizer(res, d, nlist,
-                                               qtype, metric, by_residual)
+                                               qtype, metric, by_residual, config)
     idx_gpu.train(to_train)
     idx_gpu.add(to_train)
 
@@ -63,8 +67,10 @@ def make_indices_train(nlist, d, qtype, by_residual, metric, clamp):
 
     res = faiss.StandardGpuResources()
     res.noTempMemory()
+    config = faiss.GpuIndexIVFScalarQuantizerConfig()
+    config.use_cuvs = False
     idx_gpu = faiss.GpuIndexIVFScalarQuantizer(res, d, nlist,
-                                               qtype, metric, by_residual)
+                                               qtype, metric, by_residual, config)
     assert(by_residual == idx_gpu.by_residual)
 
     idx_gpu.train(to_train)
