@@ -26,14 +26,16 @@ int main() {
     float* xq = new float[d * nq];
 
     for (int i = 0; i < nb; i++) {
-        for (int j = 0; j < d; j++)
+        for (int j = 0; j < d; j++) {
             xb[d * i + j] = distrib(rng);
+        }
         xb[d * i] += i / 1000.;
     }
 
     for (int i = 0; i < nq; i++) {
-        for (int j = 0; j < d; j++)
+        for (int j = 0; j < d; j++) {
             xq[d * i + j] = distrib(rng);
+        }
         xq[d * i] += i / 1000.;
     }
 
@@ -53,15 +55,17 @@ int main() {
         // print results
         printf("I=\n");
         for (int i = 0; i < 5; i++) {
-            for (int j = 0; j < k; j++)
+            for (int j = 0; j < k; j++) {
                 printf("%5zd ", I[i * k + j]);
+            }
             printf("\n");
         }
 
         printf("D=\n");
         for (int i = 0; i < 5; i++) {
-            for (int j = 0; j < k; j++)
+            for (int j = 0; j < k; j++) {
                 printf("%7g ", D[i * k + j]);
+            }
             printf("\n");
         }
 
@@ -78,15 +82,17 @@ int main() {
         // print results
         printf("I (5 first results)=\n");
         for (int i = 0; i < 5; i++) {
-            for (int j = 0; j < k; j++)
+            for (int j = 0; j < k; j++) {
                 printf("%5zd ", I[i * k + j]);
+            }
             printf("\n");
         }
 
         printf("D (5 last results)=\n");
         for (int i = nq - 5; i < nq; i++) {
-            for (int j = 0; j < k; j++)
+            for (int j = 0; j < k; j++) {
                 printf("%5f ", D[i * k + j]);
+            }
             printf("\n");
         }
 
